@@ -23,7 +23,7 @@ __copyright__ = '(C) 2014-2015, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = 'a86bec25ebddd442bde3c6fe8ee761b22b36c26c'
+__revision__ = '307d082e3de804064a7295aa079ee6cd0e47845a'
 
 import stat
 import shutil
@@ -140,14 +140,12 @@ class Grass7Utils:
             Inline function to search for grass binaries into a folder
             with os.walk
             """
-            command = None
             if os.path.exists(folder):
                 for root, dirs, files in os.walk(folder):
                     for cmd in cmdList:
                         if cmd in files:
-                            command = os.path.join(root, cmd)
-                            break
-            return command
+                            return os.path.join(root, cmd)
+            return None
 
         if Grass7Utils.command:
             return Grass7Utils.command
