@@ -23,12 +23,12 @@ __copyright__ = '(C) 2016, Médéric Ribreux'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = 'a86bec25ebddd442bde3c6fe8ee761b22b36c26c'
+__revision__ = '307d082e3de804064a7295aa079ee6cd0e47845a'
 
 from .i import regroupRasters
 
 
-def processCommand(alg, parameters, context):
+def processCommand(alg, parameters, context, feedback):
     # Regroup rasters
     regroupRasters(alg, parameters, context, 'input', 'group')
-    alg.processCommand(parameters, context)
+    alg.processCommand(parameters, context, feedback)
