@@ -23,7 +23,7 @@ __copyright__ = '(C) 2016, Médéric Ribreux'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = 'a86bec25ebddd442bde3c6fe8ee761b22b36c26c'
+__revision__ = '307d082e3de804064a7295aa079ee6cd0e47845a'
 
 from .r_li import checkMovingWindow, configFile
 
@@ -32,5 +32,5 @@ def checkParameterValuesBeforeExecuting(alg, parameters, context):
     return checkMovingWindow(alg, parameters, context)
 
 
-def processCommand(alg, parameters, context):
-    configFile(alg, parameters, context)
+def processCommand(alg, parameters, context, feedback):
+    configFile(alg, parameters, context, feedback)
